[libc++] Remove unnecessary container constructions in setup code (#216141)
It turns out that a fair amount of the benchmark suite is spent in
unmeasured code. Amongst other things, we were constructing temporary
containers from scratch instead of assigning from an already built-up
copy, which is a lot faster.
This patch speeds up the wall time for running flat_map benchmarks by
approximately 30s (from 98s to 66s) on my machine.
GitOrigin-RevId: d4e91964c3a57c2768db7946a399eb96d346b2c5
1 file changed